# Vevolab Data Extraction Helper - Manual

for use with version 5.4

## installing (packaged version)

download the packaged version from github

- https://github.com/realchrisward/VevoLab_DataExtraction_Helper/releases/tag/v5.4
- unzip the archive
- to run the program, enter the unzipped folder and run main.exe

## installing (from pip)

using a python environment (python >=3.9) "`pip install vdeh`"

to run the program... "`python -m vdeh.main`""

## installing (from source)

- requires python 3 (tested on python 3.9)
- install dependencies (requirements.txt)
- to run the program, enter the /src/vdeh directory and run "`python main.py`"

## running VDEH

### select input and output files

follow GUI prompt to select the Vevolab reports

select the output filename for the extracted data

click "Extract Data"

Review your extracted data

## troubleshooting and help

Please contact the author of VDEH at christopher.ward@bcm.edu if assistance is needed or bugs are observed. Issues can also be created in the repository for this software: https://github.com/realchrisward/VevoLab_Data_Extraction_Helper/issues